--
-- Now, create all the tables we need.
-- We do this using the webcalng created account.
--

CREATE TABLE webcalngitems ( 
    webcalng_calendar      VARCHAR2(64) NOT NULL,
    webcalng_itemid        NUMBER NOT NULL,
    webcalng_modified      NUMBER,
    webcalng_user          VARCHAR2(64),
    webcalng_description   VARCHAR2(2000),
    webcalng_dateregexp    VARCHAR2(64),
    webcalng_startdate     NUMBER,
    webcalng_enddate       NUMBER,
    webcalng_starttime     NUMBER,
    webcalng_endtime       NUMBER,
    webcalng_visibility    NUMBER,
    webcalng_repeat        VARCHAR2(32),
    webcalng_repeatdays    VARCHAR2(16),
    webcalng_repeatend     NUMBER,
    webcalng_remindwho     VARCHAR2(2000),
    webcalng_remindwhen    VARCHAR2(2000),
    webcalng_remindersent  VARCHAR2(2000),
    webcalng_meetingid     VARCHAR2(80),
    webcalng_hyperlink     VARCHAR2(200),
    webcalng_notes         VARCHAR2(2000),
    webcalng_exported      NUMBER,
    webcalng_color         VARCHAR2(16) );
CREATE INDEX webcalngitemsindex ON webcalngitems (webcalng_calendar, webcalng_itemid);
CREATE SEQUENCE webcalng_itemidseq START WITH 1 INCREMENT BY 1 CACHE 10;
CREATE TRIGGER webcalng_itemidtrigger BEFORE INSERT ON webcalngitems
FOR EACH ROW
WHEN (new.webcalng_itemid IS NULL)
BEGIN
  SELECT webcalng_itemidseq.nextval INTO :new.webcalng_itemid FROM dual;
END;
/

CREATE TABLE webcalngexceptions ( 
    webcalng_calendar      VARCHAR2(64) NOT NULL,
    webcalng_exceptionid   NUMBER,
    webcalng_itemid        NUMBER NOT NULL,
    webcalng_modified      NUMBER,
    webcalng_user          VARCHAR2(64),
    webcalng_description   VARCHAR2(2000),
    webcalng_exceptiondate NUMBER,
    webcalng_starttime     NUMBER,
    webcalng_endtime       NUMBER,
    webcalng_visibility    NUMBER,
    webcalng_hyperlink     VARCHAR2(200),
    webcalng_notes         VARCHAR2(2000),
    webcalng_exported      NUMBER,
    webcalng_color         VARCHAR2(16) );
CREATE INDEX webcalngexceptionsindex ON webcalngexceptions (webcalng_calendar, webcalng_exceptionid, webcalng_itemid);
CREATE SEQUENCE webcalng_exceptionidseq START WITH 1 INCREMENT BY 1 CACHE 10;
CREATE TRIGGER webcalng_exceptionidtrigger BEFORE INSERT ON webcalngexceptions
FOR EACH ROW
WHEN (new.webcalng_exceptionid IS NULL)
BEGIN
  SELECT webcalng_exceptionidseq.nextval INTO :new.webcalng_exceptionid FROM dual;
END;
/

CREATE TABLE webcalngaddresses ( 
    webcalng_calendar     VARCHAR2(64) NOT NULL,
    webcalng_addressid    NUMBER,
    webcalng_displayname  VARCHAR2(128),
    webcalng_emailaddress VARCHAR2(128),
    webcalng_phonenumber  VARCHAR2(128),
    webcalng_phonenumber2 VARCHAR2(128),
    webcalng_phonenumber3 VARCHAR2(128),
    webcalng_phonenumber4 VARCHAR2(128),
    webcalng_address1     VARCHAR2(128),
    webcalng_address2     VARCHAR2(128),
    webcalng_city         VARCHAR2(128),
    webcalng_state        VARCHAR2(64),
    webcalng_postal       VARCHAR2(32),
    webcalng_country      VARCHAR2(64),
    webcalng_other        VARCHAR2(512),
    webcalng_global       NUMBER );
CREATE INDEX webcalngaddressesindex ON webcalngaddresses (webcalng_calendar, webcalng_addressid);
CREATE SEQUENCE webcalng_addressidseq START WITH 1 INCREMENT BY 1 CACHE 10;
CREATE TRIGGER webcalng_addressidtrigger BEFORE INSERT ON webcalngaddresses
FOR EACH ROW
WHEN (new.webcalng_addressid IS NULL)
BEGIN
  SELECT webcalng_addressidseq.nextval INTO :new.webcalng_addressid FROM dual;
END;
/

CREATE TABLE webcalngtasks ( 
    webcalng_calendar VARCHAR2(64) NOT NULL,
    webcalng_taskid   NUMBER,
    webcalng_taskdata VARCHAR2(2000),
    webcalng_taskdone NUMBER );
CREATE INDEX webcalngtasksindex ON webcalngtasks (webcalng_calendar, webcalng_taskid);
CREATE SEQUENCE webcalng_taskidseq START WITH 1 INCREMENT BY 1 CACHE 10;
CREATE TRIGGER webcalng_taskidtrigger BEFORE INSERT ON webcalngtasks
FOR EACH ROW
WHEN (new.webcalng_taskid IS NULL)
BEGIN
  SELECT webcalng_taskidseq.nextval INTO :new.webcalng_taskid FROM dual;
END;
/

CREATE TABLE webcalngmeetings ( 
    webcalng_calendar  VARCHAR2(64) NOT NULL,
    webcalng_meetingid VARCHAR2(80) NOT NULL,
    webcalng_id        VARCHAR2(128),
    webcalng_password  VARCHAR2(8),
    webcalng_response  NUMBER,
    webcalng_note      VARCHAR2(2000) );
CREATE INDEX webcalngmeetingsindex ON webcalngmeetings (webcalng_calendar, webcalng_meetingid);

CREATE TABLE webcalngpreferences ( 
    webcalng_calendar VARCHAR2(64) NOT NULL,
    webcalng_key      VARCHAR2(32),
    webcalng_value    VARCHAR2(128),
    webcalng_options  VARCHAR2(2000),
    webcalng_category VARCHAR2(32),
    webcalng_usermod  NUMBER,
    webcalng_order    NUMBER );
CREATE INDEX webcalngpreferencesindex ON webcalngpreferences (webcalng_calendar, webcalng_key);

CREATE TABLE webcalngcalendars ( 
    webcalng_calendar  VARCHAR2(64) NOT NULL,
    webcalng_owner     VARCHAR2(64),
    webcalng_type      VARCHAR2(16) );
CREATE INDEX webcalngcalendarsindex ON webcalngcalendars (webcalng_calendar);

CREATE TABLE webcalngmessagequeue ( 
    webcalng_index   NUMBER,
    webcalng_email   VARCHAR2(128),
    webcalng_message VARCHAR2(2000) );
CREATE INDEX webcalngmessagequeueindex ON webcalngmessagequeue (webcalng_index);
CREATE SEQUENCE webcalng_indexseq START WITH 1 INCREMENT BY 1 CACHE 10;
CREATE TRIGGER webcalng_indextrigger BEFORE INSERT ON webcalngmessagequeue
FOR EACH ROW
WHEN (new.webcalng_index IS NULL)
BEGIN
  SELECT webcalng_indexseq.nextval INTO :new.webcalng_index FROM dual;
END;
/

CREATE TABLE webcalngpasswords ( 
    webcalng_username  VARCHAR2(32),
    webcalng_password  VARCHAR2(32) );
CREATE INDEX webcalngpasswordsindex ON webcalngpasswords (webcalng_username);

CREATE TABLE webcalnggroups ( 
    webcalng_username  VARCHAR2(32),
    webcalng_groupname  VARCHAR2(32) );
CREATE INDEX webcalnggroupsindex ON webcalnggroups (webcalng_username);

CREATE TABLE webcalngsessions ( 
    webcalng_sessionkey VARCHAR2(64) NOT NULL,
    webcalng_username   VARCHAR2(32),
    webcalng_time       NUMBER );
CREATE INDEX webcalngsessionsindex ON webcalngsessions (webcalng_sessionkey);

--
-- Create the admin user account with the default password hash.
--
INSERT INTO webcalngpasswords VALUES ('admin','HNQe.3g7DHDAQ');

--
-- Populate the preferences table with the default admin preference settings.
--
INSERT INTO webcalngpreferences VALUES('admin','start_image',NULL,NULL,'admin',0,1);
INSERT INTO webcalngpreferences VALUES('admin','start_link','http://www.webcalng.com',NULL,'admin',0,2);
INSERT INTO webcalngpreferences VALUES('admin','start_link_text','Visit the webcalng Homepage',NULL,'admin',0,3);
INSERT INTO webcalngpreferences VALUES('admin','header_link','webcalng.pl',NULL,'admin',0,4);
INSERT INTO webcalngpreferences VALUES('admin','header_image','',NULL,'admin',0,5);
INSERT INTO webcalngpreferences VALUES('admin','create_cal_all','1','0:1','admin',1,6);
INSERT INTO webcalngpreferences VALUES('admin','allow_html','0','0:1','admin',1,7);
INSERT INTO webcalngpreferences VALUES('admin','user_add_global','0','0:1','admin',1,8);
INSERT INTO webcalngpreferences VALUES('admin','log_transactions','0','0:1','admin',1,9);
INSERT INTO webcalngpreferences VALUES('admin','import_calendars',NULL,NULL,'interaction',1,1);
INSERT INTO webcalngpreferences VALUES('admin','export_calendars',NULL,NULL,'interaction',1,2);
INSERT INTO webcalngpreferences VALUES('admin','read_access',NULL,NULL,'interaction',1,3);
INSERT INTO webcalngpreferences VALUES('admin','write_access',NULL,NULL,'interaction',1,4);
INSERT INTO webcalngpreferences VALUES('admin','show_cal_name','1','0:1','interaction',1,5);
INSERT INTO webcalngpreferences VALUES('admin','show_added','0','0:1','interaction',1,6);
INSERT INTO webcalngpreferences VALUES('admin','only_add_remove','0','0:1','interaction',1,7);
INSERT INTO webcalngpreferences VALUES('admin','overlapping','1','0:1','interaction',1,8);
INSERT INTO webcalngpreferences VALUES('admin','force_wap','0','0:1','interaction',1,9);
INSERT INTO webcalngpreferences VALUES('admin','showglobal','0','0:1','interaction',1,10);
INSERT INTO webcalngpreferences VALUES('admin','squsers','0','0:1','interaction',1,11);
INSERT INTO webcalngpreferences VALUES('admin','theme','basic','dir:themes','layout_colors',1,1);
INSERT INTO webcalngpreferences VALUES('admin','show_footer_links','1','0:1','layout_colors',1,2);
INSERT INTO webcalngpreferences VALUES('admin','show_empty_hours','1','0:1','layout_colors',1,3);
INSERT INTO webcalngpreferences VALUES('admin','confirm_delete','0','0:1','layout_colors',1,4);
INSERT INTO webcalngpreferences VALUES('admin','background','#FFFFFF','color','layout_colors',1,5);
INSERT INTO webcalngpreferences VALUES('admin','bordercolor','#000099','color','layout_colors',1,6);
INSERT INTO webcalngpreferences VALUES('admin','hyperlinks','#3333FF','color','layout_colors',1,7);
INSERT INTO webcalngpreferences VALUES('admin','textcolor','#000000','color','layout_colors',1,8);
INSERT INTO webcalngpreferences VALUES('admin','textbackground','#CCCCCC','color','layout_colors',1,9);
INSERT INTO webcalngpreferences VALUES('admin','weekdays','#FFFFFF','color','layout_colors',1,10);
INSERT INTO webcalngpreferences VALUES('admin','weekends','#EEEEEE','color','layout_colors',1,11);
INSERT INTO webcalngpreferences VALUES('admin','current_day','#CCFFFF','color','layout_colors',1,12);
INSERT INTO webcalngpreferences VALUES('admin','not_a_day','#DDDDDD','color','layout_colors',1,13);
INSERT INTO webcalngpreferences VALUES('admin','language','english','dir:language','localization',1,1);
INSERT INTO webcalngpreferences VALUES('admin','timezone',NULL,'GMT-12(IDLW):GMT-11(NT):GMT-10(AHST):GMT-09(YST):GMT-08(PST):GMT-07(MST):GMT-06(CST):GMT-05(EST):GMT-04(AST):GMT-03():GMT-02(AT):GMT-01(WAT):00(GMT):GMT+01(CET):GMT+02(EET):GMT+03(BT):GMT+04(ZP4):GMT+05(ZP5):GMT+06(ZP6):GMT+07(ZP7):GMT+08(WAST):GMT+09(JST):GMT+09.5(ACT):GMT+10(EAST):GMT+11():GMT+12(IDLE)','localization',1,2);
INSERT INTO webcalngpreferences VALUES('admin','time_format','12','12:24','localization',1,3);
INSERT INTO webcalngpreferences VALUES('admin','day_start','8','0:1:2:3:4:5:6:7:8:9:10:11:12:13:14:15:16:17:18:19:20:21:22:23','localization',1,4);
INSERT INTO webcalngpreferences VALUES('admin','day_end','17','1:2:3:4:5:6:7:8:9:10:11:12:13:14:15:16:17:18:19:20:21:22:23:24','localization',1,5);
INSERT INTO webcalngpreferences VALUES('admin','date_format','0','0:1','localization',1,6);
INSERT INTO webcalngpreferences VALUES('admin','dow_start_mon','0','0:1','localization',1,7);
INSERT INTO webcalngpreferences VALUES('admin','email',NULL,NULL,'reminders',1,1);
INSERT INTO webcalngpreferences VALUES('admin','send_email','1','0:1','reminders',1,2);
INSERT INTO webcalngpreferences VALUES('admin','auto_add_event','0','0:1','reminders',1,3);
INSERT INTO webcalngpreferences VALUES('admin','show_cals_in_remind','1','0:1','reminders',1,4);
COMMIT;
