<?php

//
// This plugin integrates webcalng into Squirrelmail.
// Plugin Version 1.0
//

include_once("webcalng_functions.php");

// Plugin initialization.
function squirrelmail_plugin_init_webcalng() {
    global $squirrelmail_plugin_hooks;

    // Read in webcalng config file.
    webcalng_read_config();

    // This hook creates a squirrelmail preference for the webcalng calendar
    // name to use.
    $squirrelmail_plugin_hooks['optpage_register_block']['webcalng'] = 'webcalng_options';

    // This hook creates a cookie to log the user into webcalng 
    // after they login to squirrelmail.
    $squirrelmail_plugin_hooks['login_verified']['webcalng'] = 'webcalng_login';

    // This hook logs the user out of webcalng when they logout of squirrelmail.
    $squirrelmail_plugin_hooks['logout']['webcalng'] = 'webcalng_logout';

    // This hook places the webcalng link at the top of the squirrelmail 
    // messages page.
    $squirrelmail_plugin_hooks['menuline']['webcalng'] = 'webcalng_menuline';

    // This hook places a special week view of webcalng at the bottom of the
    // squirrelmail messages page.
    $squirrelmail_plugin_hooks['right_main_bottom']['webcalng'] = 'webcalng_weekview';
}

// Login the user to webcalng, if this user has a webcalng calendar setup. 
function webcalng_login() {
    global $webcalng_webcal, $webcalng_http, $webcalng_http_host,
           $webcalng_calendar, $webcalng_sq_secret, $data_dir;

    // See if we should log this user into webcalng.  In order for an automatic
    // login to webcalng to take place, 2 conditions must be met:
    //   1. There must be a sqmail preference telling us what webcalng calendar to access.
    //   2. The preferences for the given calendar in webcalng must give access rights to
    //      the sqmail user.
    $webcalng_cookie   = 0;
    sqgetGlobalVar('username', $username, SQ_SESSION);
    $webcalng_calendar = getPref($data_dir, $username, 'webcalng_calendar');
    $webcalng_calendar = preg_replace("/\s+/", "+", $webcalng_calendar);
    if ($webcalng_calendar) {
        $sqseed    = time();
        $sqkeyseed = $webcalng_sq_secret . $sqseed;
        $sqkey     = md5($sqkeyseed);
        // Hard code this to http for now, as the file function does
        // not seem to support https.  Should be no problem as this
        // connection to webcalng is not really going over the network.
        $url       = "http://" . $webcalng_http_host . $webcalng_webcal . "?op=sqauth&calendar=" . $webcalng_calendar . "&squser=" . $username . "&sqseed=" . $sqseed . "&sqkey=" . $sqkey;
        $lines     = file ($url);
        foreach ($lines as $line) {
            if (preg_match ('/=/', $line)) {
                list ($key, $value) = preg_split ('/=/', $line);
                if ($key == "COOKIE")
                    $webcalng_cookie = $value;
            }
        }
    }

    // If they can be automatically logged in, create a webcalng 
    // session and a cookie for it.  Set that cookie for the 
    // browser as well as within webcalng.
    if ($webcalng_cookie) {
        sqsession_register('1', 'webcalng_logged_in');
        sqsession_register($webcalng_cookie, 'webcalng_session');
        setcookie('webcalng_session',$webcalng_cookie,0,$webcalng_webcal);
    }
}

// Log the user out of webcalng. 
function webcalng_logout() {
    global $webcalng_webcal, $webcalng_http, $webcalng_http_host,
           $webcalng_calendar, $webcalng_sq_secret;

    // Call webcalng to remove the session from webcalng, then unregister
    // the state with sqsession and set the webcalng logout cookie.
    sqgetGlobalVar('username',$username);
    $sqseed      = time();
    $sqkeyseed   = $webcalng_sq_secret . $sqseed;
    $sqkey       = md5($sqkeyseed);
    sqgetGlobalVar('webcalng_session',$webcalng_session);
    // Hard code this to http for now, as the file function does
    // not seem to support https.  Should be no problem as this
    // connection to webcalng is not really going over the network.
    $url         = "http://" . $webcalng_http_host . $webcalng_webcal . "?op=sqlogout&session_key=" . $webcalng_session . "&sqseed=" . $sqseed . "&sqkey=" . $sqkey;
    $result      = file ($url);
    sqsession_unregister('webcalng_logged_in');
    setcookie('webcalng_session','invalid',0,$webcalng_webcal);
}

// Add webcalng link to upper menu.
function webcalng_menuline() {
    displayInternalLink('plugins/webcalng/webcalng.php',"webcalng",'right');
    echo "&nbsp;&nbsp;\n";
}

// Show a week view from webcalng under the messages, if they have a webcalng
// calendar setup.
function webcalng_weekview() {
    global $webcalng_webcal, $webcalng_http, $webcalng_http_host,
           $webcalng_calendar, $webcalng_sq_secret;

    sqgetGlobalVar('webcalng_logged_in',$webcalng_logged_in);
    if ($webcalng_logged_in == 1) {
        echo "<br>\n";
        sqgetGlobalVar('username',$username);
        $webcalng_calendar = getPref($data_dir, $username, 'webcalng_calendar');
        $webcalng_calendar = preg_replace("/\s+/", "+", $webcalng_calendar);
        $sqseed    = time();
        $sqkeyseed = $webcalng_sq_secret . $sqseed;
        $sqkey     = md5($sqkeyseed);
	// Hard code this to http for now, as the file function does
	// not seem to support https.  Should be no problem as this
	// connection to webcalng is not really going over the network.
        $url       = "http://" . $webcalng_http_host . $webcalng_webcal . "?op=sqweek&calendar=" . $webcalng_calendar . "&sqseed=" . $sqseed . "&sqkey=" . $sqkey;
        $lines     = file ($url);
        foreach ($lines as $line) {
            echo $line;
        }
    } 
}

// This function just sets the needed variables for the webcalng options page.
function webcalng_options() {
    global $optpage_blocks;

    $optpage_blocks[] = array(
        'name' => _("webcalng Options"),
        'url'  => '../plugins/webcalng/options.php',
        'desc' => _("Allows you to specify which webcalng calendar you would like to access automatically when logging into SquirrelMail."),
        'js'   => FALSE,
    );

}

?>
